pilas.ejemplos.syntax

Package pilas :: Package ejemplos :: Module syntax |
[hide private]
[frames] | no frames]

# Module syntax

source code

Classes | [hide private]
| PythonHighlighter Syntax highlighter for the Python language.

Functions | [hide private]
format(color, style='') Return a QTextCharFormat with the given attributes. | source code

Variables | [hide private]
| STYLES = `{'keyword': format('blue'), 'operator': format('red')`...``

Variables Details | [hide private]

  ### STYLES Value:
      {'keyword': format('blue'), 'operator': format('red'), 'brace': format
      ('darkGray'), 'defclass': format('black', 'bold'), 'string': format('m
      agenta'), 'string2': format('darkMagenta'), 'comment': format('darkGre
      en', 'italic'), 'self': format('black', 'italic'), 'numbers': format('
      brown'),}